# frozen_string_literal: true

module Codebreakergem
  class FileWorker
    PERMITTED_CLASSES = [Symbol].freeze

    class << self
      def read_from_file(filename)
        return unless File.file?(Game::FILE)

        YAML.safe_load(File.read(filename), PERMITTED_CLASSES, [], true)
      end

      def add_to_file(filename, data)
        if File.file?(filename)
          data_in_file = YAML.safe_load(File.read(filename), PERMITTED_CLASSES, [], true)
          data_in_file.is_a?(Array) ? data_in_file << data : data_in_file = [data_in_file, data]
          write_to_file(filename, data_in_file)
        else
          write_to_file(filename, data)
        end
      end

      def write_to_file(filename, data)
        File.open(filename, 'w') { |file| file.write(data.to_yaml) }
      end
    end
  end
end
